import {select, csv, scaleLinear, max, extent, axisLeft, axisBottom, format, scaleTime, area, curveBasis} from 'd3';

const svg = select('svg');
const circle = svg.append('circle');

const width = +(svg.attr('width'));
const height = +(svg.attr('height'));

const render = data => {
  const title = 'Area Chart Template';
  const xValue = d => d.year;
  const xAxisLabel = 'Time';
  const yValue = d => d.population;
  const circleRadius = 8;
  const yAxisLabel = 'Population';
  const margin = {top:50, right:40, bottom: 60, left: 80};
  const innerWidth = width - margin.left - margin.right;
  const innerHeight = height - margin.top - margin.bottom;
  
  const xScale = scaleTime()
  		.domain(extent(data, xValue))
  		.range([0, innerWidth])
  		.nice();
  
  const yScale = scaleLinear()
  		.domain([0, max(data, yValue)])
  		.range([innerHeight, 0])
  		.nice();
  
  const yAxisTickFormat = number => format('.1s')(number).replace('G', 'B');
  
  const yAxis = axisLeft(yScale)
  		.tickFormat(yAxisTickFormat)
  		.tickSize(-innerWidth)
  		.tickPadding(10);
  
  const g = svg.append('g')
  		.attr('transform', 'translate('+margin.left+', '+margin.top+')');
  
  const xAxis = axisBottom(xScale)
  							// .tickFormat(xAxisTickFormat)
  		.ticks(6)
  		.tickSize(-innerHeight)
  		.tickPadding(10);
  
  const yAxisG = g.append('g').call(yAxis);
  yAxisG.selectAll('.domain').remove();
  
  yAxisG.append('text')
  	.attr('class', 'axis-label')
  	.attr('y', -40)
  	.attr('x', -innerHeight / 2)
  	.attr('fill', 'black')
  	.attr('transform', 'rotate(-90)')
  	.attr('text-anchor', 'middle')
  	.text(yAxisLabel);
  
  const xAxisG = g.append('g').call(xAxis)
  	.attr('transform', 'translate(0,'+innerHeight+')');
  
  xAxisG.select('.domain').remove();
  
  xAxisG.append('text')
  	.attr('class', 'axis-label')
  	.attr('y', 40)
  	.attr('x', innerWidth/2-20)
    .attr('fill', 'black')
  	.text(xAxisLabel);
  
	// g.selectAll('circle').data(data)
	// 	.enter().append('circle')
	// 	.attr('cy', d => yScale(yValue(d)))
	// 	.attr('cx', d => xScale(xValue(d)))
	// 	.attr('r', circleRadius);
  
  svg.append('text')
  	.attr('class', 'title-label')
  	.attr('x', width / 2)
  	.attr('y', 40)
  	.text(title);
};

csv('https://vizhub.com/curran/datasets/world-population-by-year-2015.csv').then(data => {
	data.forEach(d => {
  	d.year = new Date(d.year);
    d.population = +d.population;
  });
  render(data);
});